@@ -5,19 +5,23 @@
 // You must place <div id="ajax-modal" class="modal hide fade" tabindex="-1"></div>
 // at the end of your base.html
 
-function renderModal($modal, data, textStatus, jqXHR) {
+function renderModal($modal, data, textStatus, jqXHR, isNormalDiv) {
     // Helper function that either executes the redirect or renders the modal
     if (jqXHR.status == 278) {
         window.location.href = jqXHR.getResponseHeader("Location");
     } else {
         $('body').modalmanager('loading');
         $modal.html(data);
-        $modal.modal();
+        if (isNormalDiv) {
+           // do nothing 
+        } else {
+            $modal.modal();
+        }
     }
 }
 
 
-function getModal(url, get_data, $wrapper) {
+function getModal(url, get_data, $wrapper, isNormalDiv) {
     // Calls the modal with a GET request.
     //
     // :param url: The url that should return the modal's template
@@ -30,13 +34,13 @@ function getModal(url, get_data, $wrapper) {
     }
     $('body').modalmanager('loading');
     $.get(url, get_data, function(data, textStatus, jqXHR) {
-        renderModal($modal, data, textStatus, jqXHR);
+        renderModal($modal, data, textStatus, jqXHR, isNormalDiv);
     });
     return false;
 }
 
 
-function postModal(url, $form, $wrapper) {
+function postModal(url, $form, $wrapper, isNormalDiv) {
     // Calls the modal with a POST request.
     //
     // :param url: The url that should return the modal's template
@@ -49,6 +53,6 @@ function postModal(url, $form, $wrapper) {
     }
     $('body').modalmanager('loading');
     $.post(url, $form.serializeArray(), function(data, textStatus, jqXHR) {
-        renderModal($modal, data, textStatus, jqXHR);
+        renderModal($modal, data, textStatus, jqXHR, isNormalDiv);
     });
 }
